from django.conf import settings
from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, SEOModel
from jmb.i18n.models import TranslationModel, I18NModel
from jmb.l10n.models import Country
from jmb.core.db.fields import HTMLField, HTMLFieldTinyMCE
from jmb.organization.models import Organization

##############################
# BANCA                      #
##############################
class Bank(DateModel, UserModel, StatusModel):
    """
    Stores banks
    MODELS:
    :model: `organization.Organization`
    """
    organization = models.ForeignKey (
        Organization,
        related_name = 'banks',
        verbose_name = _("organization"),
    )
    abi = models.CharField (
        max_length = 5,
        db_index = True,
        verbose_name = _("abi"),
    )
    cab = models.CharField (
        max_length = 5,
        db_index = True,
        verbose_name = _("cab"),
    )
    int_code = models.CharField (
        max_length = 4,
        blank = True,
        null = True,
        verbose_name = _("Int code")
    )
    cin = models.CharField (
        max_length = 1,
        blank = True,
        null = True,
        verbose_name = _("CIN")
    )
    cc = models.CharField (
        max_length = 12,
        blank = True,
        null = True,
        verbose_name = _("CC")
    )
    note = models.TextField (
        max_length = 255,
        blank = True, null = True,
        verbose_name = _("Note"),
    )

    def get_iban(self):
        """
        Returns iban
        """
        return str(self.int_code) + str(self.cin) + str(self.abi) + str(self.cab) + str(self.cc)
    iban = property(get_iban)

    def get_detail_bank(self):
        """
        Return an object DetailBank with abi and cab of Bank
        """
        try:
            return DetailBank.objects.get(abi=self.abi, cab=self.cab)
        except:
            return None

    class Meta:
        verbose_name = _("bank")
        verbose_name_plural = _("banks")

    def __unicode__(self):
        return u"%s" % self.iban

class BankDetail (DateModel, UserModel, StatusModel):
    abi = models.CharField (
        max_length = 5,
        db_index = True,
        verbose_name = _("abi"),
    )
    cab = models.CharField (
        max_length = 5,
        db_index = True,
        verbose_name = _("cab"),
    )
    name = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("name"),
    )
    agency = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("agency"),
    )
    address = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("address"),
    )
    zip_code = models.CharField (
        max_length = 5,
        db_index = True,
        verbose_name = _("zip code"),
    )
    locality = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("locality"),
    )
    province = models.CharField (
        max_length = 2,
        db_index = True,
        verbose_name = _("province"),
    )
    country = models.ForeignKey (
        Country,
        db_index = True,
        default = 108, # id of Italy Country
        verbose_name = _("country"),
    )

    class Meta:
        verbose_name = _("bank detail")
        verbose_name_plural = _("bank details")
        unique_together = (('abi', 'cab'),)

# if settings.CMS_ENABLED:
#     import namespace.appname.model.cms.plugins
#     import namespace.appname.model.cms.app
